<h1 align="center">
  guap
</h1>

<h3 align="center">
 From algorithms outputs to business outcomes.
</h3>
<p align="center">
guap is an open-source python package that helps data team to get an ML evaluation metrics everyone can agree on by converting your model output to business outcomes, a.k.a. profits.</p>

<h3 align="center">
 🤖 🪄 📈
</h3>


<p align="center">
  <img src="https://i.imgur.com/sCfpF6d.png">
</p>

<p align="center">
    <a href="https://github.com/chetanraj/awesome-github-badges">
        <img alt="Made with love" src="https://img.shields.io/badge/Made%20With-Love-orange.svg">
    </a>
	<a href="https://github.com/chetanraj/awesome-github-badges">
        <img alt="py version" src="https://img.shields.io/badge/python-3.6_|_3.7_|_3.8-blue">
    </a>
	    </a>
	<a href="https://github.com/chetanraj/awesome-github-badges">
        <img alt="version" src="https://img.shields.io/badge/version-0.1.0-gree">
    </a>
</p>


## 🧞‍♂️ Why should I use guap?
Our mission with guap is to align all stakeholders with measurable business outcomes by including the three core teams — business, data science and IT — throughout the life cycle of the AI models.

- Make collaboration healthier and clearer between tech and non-tech people
- Make better decisions at every stage of the ML project lifecycle

Want to know more? Read [Why guap exist](https://ulyssebottello.com/why-guap/).

## ✨ Features
We're on the journey to make sure every ML use-case that go to production is a valuable one. And it starts with a simple way to estimate the expected profit/cost of a model based on its confusion matrix.

- **Get the total profit** Based on the test set, guap will give you the total expected profit based on the cost matrix. A great way to have an overview of the model profitability.
- **Average profit per prediction** Along the total profit score, guap will give you the average profit/cost per prediction. Perfect if you have costs per prediction, or if you need to estimate the profitability while scaling.

That's it...for now! Keep up-to-date with release announcements on Twitter [@guap_ml](https://twitter.com/guap_ml)!

## 🪄 Quickstart Install
First install the package using pip

```
pip install guap
```

Then, you can follow our instructions using the Google Colab demo. We're writing the documentation right now.

## ⌛ Status
- [x] Alpha: We are demoing guap to users and receiving feedback
- [ ] Private Beta
- [ ] Public Beta
- [ ] Official Launch

Watch "releases" of this repo to get notified of major updates, and give the star button a click whilst you're there.

## 🙏 Contributing
Pull requests are welcome. You don't know where to start? let's talk [@guap_ml](https://twitter.com/guap_ml)!

## 💖 License
[Apache License 2.0](http://www.apache.org/licenses/)
